@@ -20,13 +20,15 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
+#include <gtk/gtktable.h>
+#include <gtk/gtkwindow.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
 #include <libgnomedb/gnome-db-stock.h>
-#include <libgnomeui/gnome-window-icon.h>
-#include <bonobo/bonobo-i18n.h>
+#include <libgnomedb/gnome-db-util.h>
+#include "gnome-db-i18n.h"
 
 struct _GnomeDbLoginDialogPrivate {
 	GtkWidget *login;
@@ -86,18 +88,47 @@ gnome_db_login_dialog_class_init (GnomeDbLoginDialogClass *klass)
 static void
 gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass *klass)
 {
+	GtkWidget *hbox, *vbox, *image, *label;
+
 	g_return_if_fail (GNOME_DB_IS_LOGIN_DIALOG (dialog));
 
 	dialog->priv = g_new0 (GnomeDbLoginDialogPrivate, 1);
-
+        
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GNOME_DB_STOCK_CONNECT, GTK_RESPONSE_OK);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
+        gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 12);
+        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+        gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
+	gtk_widget_show (hbox);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
+
+	/* image = gtk_image_new_from_stock (GNOME_DB_STOCK_DATABASE, GTK_ICON_SIZE_DIALOG); */
+	image = gtk_image_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db-database-login_48x48.png");
+        gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+	gtk_widget_show (image);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+
+	vbox = gtk_vbox_new (FALSE, 12);
+	gtk_widget_show (vbox);
+	
+	label = gnome_db_new_label_widget (_("Enter the arguments below to open a connection\n"
+					     "to a data source"));
+	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+        gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
+
 	dialog->priv->login = gnome_db_login_new (NULL);
 	gtk_widget_show (dialog->priv->login);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), dialog->priv->login,
-			    TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->login, TRUE, TRUE, 0);
+	
+	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 }
 
 static void
@@ -195,8 +226,8 @@ gnome_db_login_dialog_new (const gchar *title)
 
 	dialog = g_object_new (GNOME_DB_TYPE_LOGIN_DIALOG, NULL);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
-	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
-					 LIBGNOMEDB_ICONSDIR "/gnome-db.png");
+	gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
+					 LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
 
 	return GTK_WIDGET (dialog);
 }
